package Drawnings;

import java.awt.*;
import java.util.Random;
import Entities.*;
import MovementStrategy.*;

public class DrawningAirbus {

    public EntityAirbus entityAirbus;
    public IDrawningPortholes _portholes;
    private int _pictureWidth;
    private int _pictureHeight;
    protected int _startPosX;
    protected int _startPosY;
    private int _airbusWidth = 124;
    private int _airbusHeight = 44;

    // Получение объекта IMoveableObject из объекта DrawningCar;
    public IMoveableObject GetMoveableObject() {
        return new DrawningObjectAirbus(this);
    }

    public int GetPosX() { return  _startPosX; }
    public int GetPosY() { return _startPosY; }
    public int GetWidth() { return  _airbusWidth; }
    public int GetHeight() { return  _airbusHeight; }

    public DrawningAirbus(int speed, float weight, Color bodyColor, int countPortholes, int width, int height) {
        if (width < _airbusHeight || height < _airbusWidth)
            return;
        _pictureWidth = width;
        _pictureHeight = height;
        entityAirbus = new EntityAirbus(speed, weight, bodyColor);

        Random random = new Random();
        switch (random.nextInt(0,3)) {
            case 0:
                _portholes = new DrawningPortholesCircle();
                break;
            case 1:
                _portholes = new DrawningPortholesHeart();
                break;
            case 2:
                _portholes = new DrawningPortholesSquare();
                break;
            default:
                _portholes = new DrawningPortholesCircle();
                break;
        }
        _portholes.SetCount(countPortholes);
    }

    public void SetPosition (int x, int y) {
        if (x + _airbusWidth > _pictureWidth || y + _airbusHeight > _pictureHeight) {
            _startPosX = _pictureWidth - _airbusWidth;
            _startPosY = _pictureHeight - _airbusHeight;
        }
        else
        {
            _startPosX = x;
            _startPosY = y;
        }
    }

    public boolean CanMove(Direction direction)
    {
        if (entityAirbus == null)
        {
            return false;
        }
        switch (direction)
        {
            case Left:
                return _startPosX - entityAirbus.Step > 0;
            case Right:
                return _startPosX + _airbusWidth + entityAirbus.Step < _pictureWidth;
            case Up:
                return _startPosY - entityAirbus.Step > 0;
            case Down:
                return _startPosY + _airbusHeight + entityAirbus.Step < _pictureHeight;
            default:
                return false;
        }
    }

    public void MoveTransport(Direction direction){
        if (entityAirbus == null) {
            return;
        }

        switch (direction) {
            case Left:
            _startPosX -= entityAirbus.Step;
            break;
        case Right:
            _startPosX += entityAirbus.Step;
            break;
        case Up:
            _startPosY -= entityAirbus.Step;
            break;
        case Down:
            _startPosY += entityAirbus.Step;
            break;
        }
    }

    public void DrawTransport(Graphics2D g) {

        if (entityAirbus == null) {
            return;
        }
        // тело
        g.setColor(entityAirbus.getBodyColor());
        g.fillRect(_startPosX+3, _startPosY+17, 103, 20);
        g.setColor(Color.BLACK);
        g.drawRect(_startPosX+3, _startPosY+17, 103, 20);

        // иллюминаторы
        _portholes.Draw(g, _startPosX, _startPosY);

        // нос
        int[] xPolygonNoise = {_startPosX+106, _startPosX + 120, _startPosX+106,};
        int[] yPolygonNoise = {_startPosY+17, _startPosY+27, _startPosY+37};

        g.setColor(entityAirbus.getBodyColor());
        g.fillPolygon(xPolygonNoise, yPolygonNoise, xPolygonNoise.length);
        g.setColor(Color.BLACK);
        g.drawPolygon(xPolygonNoise, yPolygonNoise, xPolygonNoise.length);

        // хвост
        int[] xPolygonTale = { _startPosX+2, _startPosX+27, _startPosX+2};
        int[] yPolygonTale = {_startPosY, _startPosY + 18,_startPosY+18};
        g.setColor(entityAirbus.getBodyColor());
        g.fillPolygon(xPolygonTale, yPolygonTale, xPolygonTale.length);
        g.setColor(Color.BLACK);
        g.drawPolygon(xPolygonTale, yPolygonTale, xPolygonTale.length);

        // крыло
        g.setColor(Color.BLACK);
        g.fillOval(_startPosX+43, _startPosY+25, 22, 5);
        g.drawOval(_startPosX+43, _startPosY+25, 22, 5);

        // двигатель
        g.setColor(Color.BLACK);
        g.fillOval(_startPosX+1, _startPosY+15, 19, 5);
        g.drawOval(_startPosX+1, _startPosY+15, 19, 5);

        // шасси
        g.setColor(entityAirbus.getBodyColor());
        g.fillOval(_startPosX+25,_startPosY+38, 6, 6);
        g.fillOval(_startPosX+30,_startPosY+38, 6, 6);
        g.fillOval(_startPosX+100,_startPosY+38, 6, 6);
        g.setColor(Color.BLACK);
        g.drawOval(_startPosX+25,_startPosY+38, 6, 6);
        g.drawOval(_startPosX+30,_startPosY+38, 6, 6);
        g.drawOval(_startPosX+100,_startPosY+38, 6, 6);
    }
}
